==> openGion8.0.2.0_verup.zip: META-INF/resources/jsp/common/resultScript.js <==
var $jscomp=$jscomp||{};$jscomp.scope={};$jscomp.ASSUME_ES5=!1;$jscomp.ASSUME_NO_NATIVE_MAP=!1;$jscomp.ASSUME_NO_NATIVE_SET=!1;$jscomp.SIMPLE_FROUND_POLYFILL=!1;$jscomp.ISOLATE_POLYFILLS=!1;$jscomp.FORCE_POLYFILL_PROMISE=!1;$jscomp.FORCE_POLYFILL_PROMISE_WHEN_NO_UNHANDLED_REJECTION=!1;$jscomp.defineProperty=$jscomp.ASSUME_ES5||"function"==typeof Object.defineProperties?Object.defineProperty:function(a,b,c){if(a==Array.prototype||a==Object.prototype)return a;a[b]=c.value;return a};
$jscomp.getGlobal=function(a){a=["object"==typeof globalThis&&globalThis,a,"object"==typeof window&&window,"object"==typeof self&&self,"object"==typeof global&&global];for(var b=0;b<a.length;++b){var c=a[b];if(c&&c.Math==Math)return c}throw Error("Cannot find global object");};$jscomp.global=$jscomp.getGlobal(this);$jscomp.IS_SYMBOL_NATIVE="function"===typeof Symbol&&"symbol"===typeof Symbol("x");$jscomp.TRUST_ES6_POLYFILLS=!$jscomp.ISOLATE_POLYFILLS||$jscomp.IS_SYMBOL_NATIVE;$jscomp.polyfills={};
$jscomp.propertyToPolyfillSymbol={};$jscomp.POLYFILL_PREFIX="$jscp$";var $jscomp$lookupPolyfilledValue=function(a,b){var c=$jscomp.propertyToPolyfillSymbol[b];if(null==c)return a[b];c=a[c];return void 0!==c?c:a[b]};$jscomp.polyfill=function(a,b,c,g){b&&($jscomp.ISOLATE_POLYFILLS?$jscomp.polyfillIsolated(a,b,c,g):$jscomp.polyfillUnisolated(a,b,c,g))};
$jscomp.polyfillUnisolated=function(a,b,c,g){c=$jscomp.global;a=a.split(".");for(g=0;g<a.length-1;g++){var d=a[g];if(!(d in c))return;c=c[d]}a=a[a.length-1];g=c[a];b=b(g);b!=g&&null!=b&&$jscomp.defineProperty(c,a,{configurable:!0,writable:!0,value:b})};
$jscomp.polyfillIsolated=function(a,b,c,g){var d=a.split(".");a=1===d.length;g=d[0];g=!a&&g in $jscomp.polyfills?$jscomp.polyfills:$jscomp.global;for(var f=0;f<d.length-1;f++){var h=d[f];if(!(h in g))return;g=g[h]}d=d[d.length-1];c=$jscomp.IS_SYMBOL_NATIVE&&"es6"===c?g[d]:null;b=b(c);null!=b&&(a?$jscomp.defineProperty($jscomp.polyfills,d,{configurable:!0,writable:!0,value:b}):b!==c&&(void 0===$jscomp.propertyToPolyfillSymbol[d]&&(c=1E9*Math.random()>>>0,$jscomp.propertyToPolyfillSymbol[d]=$jscomp.IS_SYMBOL_NATIVE?
$jscomp.global.Symbol(d):$jscomp.POLYFILL_PREFIX+c+"$"+d),$jscomp.defineProperty(g,$jscomp.propertyToPolyfillSymbol[d],{configurable:!0,writable:!0,value:b})))};
$jscomp.polyfill("String.prototype.replaceAll",function(a){return a?a:function(b,c){if(b instanceof RegExp&&!b.global)throw new TypeError("String.prototype.replaceAll called with a non-global RegExp argument.");return b instanceof RegExp?this.replace(b,c):this.replace(new RegExp(String(b).replace(/([-()\[\]{}+?*.$\^|,:#<!\\])/g,"\\$1").replace(/\x08/g,"\\x08"),"g"),c)}},"es_next","es3");
function getParentByTagName(a,b,c){for(;a&&b!=a.tagName;){if(c&&a.tagName==c){a=null;break}a=a.parentNode}return a}function getRowClicked(a){var b;for(b=a;b;){a=b.tagName;if(("TR"==a||"TBODY"==a)&&-1<b.className.indexOf("row_"))break;b=b.parentNode}return b}function getTable(a){return getParentByTagName(a,"TABLE")}function IsTextField(a){var b=!1;switch(a.tagName){case "TD":case "CENTER":case "SPAN":case "DIV":case "PRE":case "STYLE":case "FONT":case "B":case "STRONG":case "A":b=!0}return b}
function getCurrentStyle(a,b,c){return a.currentStyle?(b=b.replace(/\-(\w)/g,function(g,d){return d.toUpperCase()}),a.currentStyle[b]):getComputedStyle?(b=b.replace(/([A-Z])/g,"-$1").toLowerCase(),getComputedStyle(a,c||null).getPropertyValue(b)):""}var csHybsCheckMarker="h_rowSel";function getHybsChkFromTBody(a){var b;var c=null;a=a.getElementsByTagName("INPUT");for(b=0;b<a.length;b++)if(csHybsCheckMarker==a[b].name){c=a[b];break}return c}
function hilightRow(a,b,c){var g,d="undefined"==typeof hybs_csHilightBGColor?"rgb(160,230,200)":hybs_csHilightBGColor;var f=null;var h=!1;if(a=a?a:window.event?window.event:null)f=a.target?a.target:a.srcElement?a.srcElement:null,h="undefined"!=typeof a.shiftKey?a.shiftKey:a.modifiers&&a.modifiers&Event.SHIFT_MASK;if(f){a=!0;b&&f.name!=csHybsCheckMarker&&(a=!1);"INPUT"==f.tagName&&"submit"==f.type&&(a=!1);b=getRowClicked(f);var e=f.getElementsByTagName("TABLE");if(a&&0>=e.length&&b&&b.className&&0>
b.className.indexOf("row_h"))if((e=getHybsChkFromTBody(b))&&(g="radio"==e.type||"A"==f.tagName),a=getTable(b),g)a.oldTBody2&&a.oldTBody2==b||(a.oldTBody2&&(a.oldTBody2.style.backgroundColor=a.oldBGColor,a.oldRadio.checked=!1),a.oldTBody2=b,a.oldBGColor=getCurrentStyle(b,"background-color"),a.oldRadio=e,b.style.backgroundColor=d,e.checked=!0,c&&e.click());else if(h){c=a.oldTBody||b;document.documentElement.compareDocumentPosition?(f=c.compareDocumentPosition(b),f=4==f||0==f):f=c.sourceIndex<=b.sourceIndex;
f?(f=c,c=b):f=b;for(;;){f.oldBGColor||(f.oldBGColor=getCurrentStyle(f,"background-color"),f.style.backgroundColor=d);(h=getHybsChkFromTBody(f))&&!h.checked&&(h.checked=!0);if(f==c)break;do f=f.nextSibling;while(f&&1!=f.nodeType)}a.oldTBody=b}else if(e&&(f.name==csHybsCheckMarker&&!e.checked||f.name!=csHybsCheckMarker&&e.checked)||!e&&b.oldBGColor){if(f==e||IsTextField(f))b.style.backgroundColor=b.oldBGColor,b.oldBGColor="",e&&(e.checked=!1),a.oldTBody=b}else b.oldBGColor=getCurrentStyle(b,"background-color"),
b.style.backgroundColor=d,e&&(e.checked=!0),a.oldTBody=b}}
function bulkSet(a){var b,c,g;var d=a.value;var f=a.name.substring(2)+"__";"checkbox"==a.type&&"1"==d&&(d=a.checked?"1":"0");navigator.clipboard||(-1<d.indexOf("$$ ")?d=replaceAll(d,"$$ ","\t"):0>d.indexOf("\t")&&-1<d.indexOf(" ")&&alert("\u8cbc\u308a\u4ed8\u3051\u6642\u306e\u30de\u30eb\u30c1\u30da\u30fc\u30b9\u30c8\u306f\u3001\u6539\u884c\u3092\u300e$$\u300f\u306b\u7f6e\u304d\u63db\u3048\u308c\u3070\u5b9f\u884c\u3067\u304d\u307e\u3059\u3002"));a=d.split("\t");d=document.getElementsByTagName("FORM");
if(null!=d)for(g=0;g<d.length;g++){var h=d[g].elements;for(b=c=0;b<h.length;b++){var e=h[b];if(e.name&&0==e.name.indexOf(f)&&"hidden"!=e.type){if("checkbox"==e.type)e.checked="1"==a[c];else if("select-one"==e.type)e.value=a[c].split(":")[0];else if("radio"==e.type)if(e.value==a[c])e.checked=!0;else continue;else e.value=a[c];c<a.length-1&&c++;$(e).change()}}}}
function bulkPaste(a){var b,c;var g=a.name.substring(2)+"__";var d=document.getElementsByTagName("FORM");if(null!=d){for(b=0;b<d.length;b++){var f=d[b].elements;var h="";for(c=0;c<f.length;c++){var e=f[c];e.name&&0==e.name.indexOf(g)&&"hidden"!=e.type&&("checkbox"==e.type?h+=e.checked?"1":"0":"select-one"==e.type?h+=e.options[e.selectedIndex].value+":"+e.options[e.selectedIndex].text:"radio"==e.type?e.checked&&(h+=e.value):h+=e.value,h+="\t")}if("select-one"==a.type&&(f=document.getElementsByName(a.name))&&
1<f.length)for(l=0;l<f.length;l++)f[l].length++,f[l].options[a.length-1].value=h,f[l].options[a.length-1].text="Ctrl-C",f[l].selectedIndex=a.length-1}isEndInitEvent()&&$("table#viewTable").resizeView()}return h}
function bulkPasteBox(a){var b,c;var g=document.getElementsByTagName("FORM");if(null!=g){for(b=0;b<g.length;b++){var d=g[b].elements;var f="";var h=null;for(c=0;c<d.length;c++){var e=d[c];if(e.name&&"hidden"!=e.type){var k=e.name.indexOf("__");0>k||(k=e.name.substring(k+2,e.name.length),k!=h&&(null!=h&&(f+=";"),h=k),"checkbox"==e.type?f+=e.checked?"1":"0":"select-one"==e.type?f+=e.options[e.selectedIndex].value+":"+e.options[e.selectedIndex].text:"radio"==e.type?e.checked&&(f+=e.value):f+=e.value,
f+="\t")}}if("select-one"==a.type&&(d=document.getElementsByName(a.name))&&1<d.length)for(l=0;l<d.length;l++)d[l].length++,d[l].options[a.length-1].value=f,d[l].options[a.length-1].text="Ctrl-C",d[l].selectedIndex=a.length-1}isEndInitEvent()&&$("table#viewTable").resizeView()}return f}
function ctrlCV(a){var b=event.keyCode;var c=event.ctrlKey;keychar=String.fromCharCode(b).toUpperCase();if(c&&null!=a)if(event.preventDefault?(event.preventDefault(),event.stopPropagation()):(event.returnValue=!1,event.cancelBubble=!0),b=-1<navigator.userAgent.toLowerCase().indexOf("edge"),c=-1<navigator.userAgent.toLowerCase().indexOf("chrome"),b=b||c,"C"==keychar){var g=bulkPaste(a);g=null!=g?g:a.value;setClipboard(b,replaceAll(g,"\t","\r\n"))}else"B"==keychar?(g=bulkPasteBox(a),g=null!=g?g:a.value,
setClipboard(b,replaceAll(g,";","\r\n"))):"V"==keychar?getClipboard(b,function(d){g=replaceAll(d,"\r\n","\t");if("select-one"==a.type){if((d=document.getElementsByName(a.name))&&1<d.length){for(i=0;i<d.length;i++)d[i].length++,d[i].options[a.length-1].value=g,d[i].options[a.length-1].text="Ctrl-V",d[i].selectedIndex=a.length-1,d[i].value=g;isEndInitEvent()&&$("table#viewTable").resizeView()}}else a.value=g;bulkSet(a)}):"X"==keychar&&(a.value="",bulkSet(a))}
function setClipboard(a,b){a?navigator.clipboard?navigator.clipboard.writeText(b):(a=document.createElement("textarea"),a.setAttribute("id","target"),a.setAttribute("type","hidden"),a.value=b,document.body.appendChild(a),a.select(),document.execCommand("copy"),document.body.removeChild(a)):window.clipboardData.setData("text",b)}
function getClipboard(a,b){if(a)if(navigator.clipboard)navigator.clipboard.readText().then(function(g){b(g)});else{a=document.createElement("textarea");a.setAttribute("id","target");document.body.appendChild(a);a.focus();if(document.execCommand("paste")){var c=a.value;b(c)}else alert("\u30bb\u30ad\u30e5\u30ea\u30c6\u30a3\u306e\u95a2\u4fc2\u3067\u3001\u30da\u30fc\u30b9\u30c8\u3067\u304d\u307e\u305b\u3093\u3067\u3057\u305f\u3002");document.body.removeChild(a)}else c=window.clipboardData.getData("text"),
b(c)}function replaceAll(a,b,c){return a.split(b).join(c)}window.onbeforeprint=BeforPrint;window.onafterprint=AfterPrint;
function BeforPrint(){var a;var b=document.getElementsByName("divheader");var c=document.getElementsByName("layer");if(null!=b&&null!=c){for(a=0;a<b.length;a++)b[a].style.display="none";for(a=0;a<c.length;a++)c[a].oldScrollTop=c[a].scrollTop,c[a].scrollTop=0,c[a].oldWidth=c[a].style.width,c[a].style.width="",c[a].oldHeight=c[a].style.height,c[a].style.height="",c[a].oldOverflowX=c[a].style.overflowX,c[a].style.overflowX="visible",c[a].oldOverflowY=c[a].style.overflowY,c[a].style.overflowY="visible"}b=
document.getElementsByName("viewTable");if(null!=b)for(a=0;a<b.length;a++)b[a].oldFrame=b[a].frame,b[a].frame="box",b[a].oldBorderCollapse=b[a].style.borderCollapse,b[a].style.borderCollapse="collapse",b[a].oldCellspacing=b[a].cellspacing,b[a].cellspacing="0px"}
function AfterPrint(){var a;var b=document.getElementsByName("viewTable");if(null!=b)for(a=0;a<b.length;a++)b[a].style.borderCollapse=b[a].oldBorderCollapse,b[a].frame=b[a].oldFrame,b[a].cellspacing=b[a].oldCellspacing;b=document.getElementsByName("divheader");var c=document.getElementsByName("layer");if(null!=b&&null!=c){for(a=0;a<b.length;a++)b[a].style.display="block";for(a=0;a<c.length;a++)c[a].style.overflowX=c[a].oldOverflowX,c[a].style.overflowY=c[a].oldOverflowY,c[a].style.width=c[a].oldWidth,
c[a].style.height=c[a].oldHeight,c[a].scrollTop=c[a].oldScrollTop}}function setPageTiming(a){if((document.attachEvent?"complete"==document.readyState:1)&&parent.QUERY&&parent.QUERY.timecheck){a=document.getElementById("queryTime");var b=document.getElementById("viewTime");parent.QUERY.timecheck(a,b)}}
document.addEventListener?document.getBoxObjectFor?document.addEventListener("DOMContentLoaded",setPageTiming,null):window.addEventListener("load",setPageTiming,!1):document.attachEvent?document.attachEvent("onreadystatechange",setPageTiming):window.onload=setPageTiming;$(function(){$(".orgRowCntMsg").filter(":gt(0)").remove().end().filter(":first").replaceAll("#rowCountMessage")});

==> openGion8.3.1.0_verup.zip: META-INF/resources/jsp/common/resultScript.js <==
var $jscomp=$jscomp||{};$jscomp.scope={};$jscomp.ASSUME_ES5=!1;$jscomp.ASSUME_NO_NATIVE_MAP=!1;$jscomp.ASSUME_NO_NATIVE_SET=!1;$jscomp.SIMPLE_FROUND_POLYFILL=!1;$jscomp.ISOLATE_POLYFILLS=!1;$jscomp.FORCE_POLYFILL_PROMISE=!1;$jscomp.FORCE_POLYFILL_PROMISE_WHEN_NO_UNHANDLED_REJECTION=!1;$jscomp.defineProperty=$jscomp.ASSUME_ES5||"function"==typeof Object.defineProperties?Object.defineProperty:function(a,b,c){if(a==Array.prototype||a==Object.prototype)return a;a[b]=c.value;return a};
$jscomp.getGlobal=function(a){a=["object"==typeof globalThis&&globalThis,a,"object"==typeof window&&window,"object"==typeof self&&self,"object"==typeof global&&global];for(var b=0;b<a.length;++b){var c=a[b];if(c&&c.Math==Math)return c}throw Error("Cannot find global object");};$jscomp.global=$jscomp.getGlobal(this);$jscomp.IS_SYMBOL_NATIVE="function"===typeof Symbol&&"symbol"===typeof Symbol("x");$jscomp.TRUST_ES6_POLYFILLS=!$jscomp.ISOLATE_POLYFILLS||$jscomp.IS_SYMBOL_NATIVE;$jscomp.polyfills={};
$jscomp.propertyToPolyfillSymbol={};$jscomp.POLYFILL_PREFIX="$jscp$";var $jscomp$lookupPolyfilledValue=function(a,b){var c=$jscomp.propertyToPolyfillSymbol[b];if(null==c)return a[b];c=a[c];return void 0!==c?c:a[b]};$jscomp.polyfill=function(a,b,c,g){b&&($jscomp.ISOLATE_POLYFILLS?$jscomp.polyfillIsolated(a,b,c,g):$jscomp.polyfillUnisolated(a,b,c,g))};
$jscomp.polyfillUnisolated=function(a,b,c,g){c=$jscomp.global;a=a.split(".");for(g=0;g<a.length-1;g++){var d=a[g];if(!(d in c))return;c=c[d]}a=a[a.length-1];g=c[a];b=b(g);b!=g&&null!=b&&$jscomp.defineProperty(c,a,{configurable:!0,writable:!0,value:b})};
$jscomp.polyfillIsolated=function(a,b,c,g){var d=a.split(".");a=1===d.length;g=d[0];g=!a&&g in $jscomp.polyfills?$jscomp.polyfills:$jscomp.global;for(var f=0;f<d.length-1;f++){var h=d[f];if(!(h in g))return;g=g[h]}d=d[d.length-1];c=$jscomp.IS_SYMBOL_NATIVE&&"es6"===c?g[d]:null;b=b(c);null!=b&&(a?$jscomp.defineProperty($jscomp.polyfills,d,{configurable:!0,writable:!0,value:b}):b!==c&&(void 0===$jscomp.propertyToPolyfillSymbol[d]&&(c=1E9*Math.random()>>>0,$jscomp.propertyToPolyfillSymbol[d]=$jscomp.IS_SYMBOL_NATIVE?
$jscomp.global.Symbol(d):$jscomp.POLYFILL_PREFIX+c+"$"+d),$jscomp.defineProperty(g,$jscomp.propertyToPolyfillSymbol[d],{configurable:!0,writable:!0,value:b})))};
$jscomp.polyfill("String.prototype.replaceAll",function(a){return a?a:function(b,c){if(b instanceof RegExp&&!b.global)throw new TypeError("String.prototype.replaceAll called with a non-global RegExp argument.");return b instanceof RegExp?this.replace(b,c):this.replace(new RegExp(String(b).replace(/([-()\[\]{}+?*.$\^|,:#<!\\])/g,"\\$1").replace(/\x08/g,"\\x08"),"g"),c)}},"es_next","es3");
function getParentByTagName(a,b,c){for(;a&&b!=a.tagName;){if(c&&a.tagName==c){a=null;break}a=a.parentNode}return a}function getRowClicked(a){var b;for(b=a;b;){a=b.tagName;if(("TR"==a||"TBODY"==a)&&-1<b.className.indexOf("row_"))break;b=b.parentNode}return b}function getTable(a){return getParentByTagName(a,"TABLE")}function IsTextField(a){var b=!1;switch(a.tagName){case "TD":case "CENTER":case "SPAN":case "DIV":case "PRE":case "STYLE":case "FONT":case "B":case "STRONG":case "A":b=!0}return b}
function getCurrentStyle(a,b,c){return a.currentStyle?(b=b.replace(/\-(\w)/g,function(g,d){return d.toUpperCase()}),a.currentStyle[b]):getComputedStyle?(b=b.replace(/([A-Z])/g,"-$1").toLowerCase(),getComputedStyle(a,c||null).getPropertyValue(b)):""}var csHybsCheckMarker="h_rowSel";function getHybsChkFromTBody(a){var b;var c=null;a=a.getElementsByTagName("INPUT");for(b=0;b<a.length;b++)if(csHybsCheckMarker==a[b].name){c=a[b];break}return c}
function hilightRow(a,b,c){var g,d="undefined"==typeof hybs_csHilightBGColor?"rgb(160,230,200)":hybs_csHilightBGColor;var f=null;var h=!1;if(a=a?a:window.event?window.event:null)f=a.target?a.target:a.srcElement?a.srcElement:null,h="undefined"!=typeof a.shiftKey?a.shiftKey:a.modifiers&&a.modifiers&Event.SHIFT_MASK;if(f){a=!0;b&&f.name!=csHybsCheckMarker&&(a=!1);"INPUT"==f.tagName&&"submit"==f.type&&(a=!1);b=getRowClicked(f);var e=f.getElementsByTagName("TABLE");if(a&&0>=e.length&&b&&b.className&&0>
b.className.indexOf("row_h"))if((e=getHybsChkFromTBody(b))&&(g="radio"==e.type||"A"==f.tagName),a=getTable(b),g)a.oldTBody2&&a.oldTBody2==b||(a.oldTBody2&&(a.oldTBody2.style.backgroundColor=a.oldBGColor,a.oldRadio.checked=!1),a.oldTBody2=b,a.oldBGColor=getCurrentStyle(b,"background-color"),a.oldRadio=e,b.style.backgroundColor=d,e.checked=!0,c&&e.click());else if(h){c=a.oldTBody||b;document.documentElement.compareDocumentPosition?(f=c.compareDocumentPosition(b),f=4==f||0==f):f=c.sourceIndex<=b.sourceIndex;
f?(f=c,c=b):f=b;for(;;){f.oldBGColor||(f.oldBGColor=getCurrentStyle(f,"background-color"),f.style.backgroundColor=d);(h=getHybsChkFromTBody(f))&&!h.checked&&(h.checked=!0);if(f==c)break;do f=f.nextSibling;while(f&&1!=f.nodeType)}a.oldTBody=b}else if(e&&(f.name==csHybsCheckMarker&&!e.checked||f.name!=csHybsCheckMarker&&e.checked)||!e&&b.oldBGColor){if(f==e||IsTextField(f))b.style.backgroundColor=b.oldBGColor,b.oldBGColor="",e&&(e.checked=!1),a.oldTBody=b}else b.oldBGColor=getCurrentStyle(b,"background-color"),
b.style.backgroundColor=d,e&&(e.checked=!0),a.oldTBody=b}}
function bulkSet(a){var b,c,g;var d=a.value;var f=a.name.substring(2)+"__";d=autoConvert(a.className,d);"checkbox"==a.type&&"1"==d&&(d=a.checked?"1":"0");navigator.clipboard||(-1<d.indexOf("$$ ")?d=replaceAll(d,"$$ ","\t"):0>d.indexOf("\t")&&-1<d.indexOf(" ")&&alert("\u8cbc\u308a\u4ed8\u3051\u6642\u306e\u30de\u30eb\u30c1\u30da\u30fc\u30b9\u30c8\u306f\u3001\u6539\u884c\u3092\u300e$$\u300f\u306b\u7f6e\u304d\u63db\u3048\u308c\u3070\u5b9f\u884c\u3067\u304d\u307e\u3059\u3002"));a=d.split("\t");d=document.getElementsByTagName("FORM");
if(null!=d)for(g=0;g<d.length;g++){var h=d[g].elements;for(b=c=0;b<h.length;b++){var e=h[b];if(e.name&&0==e.name.indexOf(f)&&"hidden"!=e.type){if("checkbox"==e.type)e.checked="1"==a[c];else if("select-one"==e.type)e.value=a[c].split(":")[0];else if("radio"==e.type)if(e.value==a[c])e.checked=!0;else continue;else e.value=a[c];c<a.length-1&&c++;$(e).change()}}}}
function bulkPaste(a){var b,c;var g=a.name.substring(2)+"__";var d=document.getElementsByTagName("FORM");if(null!=d){for(b=0;b<d.length;b++){var f=d[b].elements;var h="";for(c=0;c<f.length;c++){var e=f[c];e.name&&0==e.name.indexOf(g)&&"hidden"!=e.type&&("checkbox"==e.type?h+=e.checked?"1":"0":"select-one"==e.type?h+=e.options[e.selectedIndex].value+":"+e.options[e.selectedIndex].text:"radio"==e.type?e.checked&&(h+=e.value):h+=e.value,h+="\t")}if("select-one"==a.type&&(f=document.getElementsByName(a.name))&&
1<f.length)for(l=0;l<f.length;l++)f[l].length++,f[l].options[a.length-1].value=h,f[l].options[a.length-1].text="Ctrl-C",f[l].selectedIndex=a.length-1}isEndInitEvent()&&$("table#viewTable").resizeView()}return h}
function bulkPasteBox(a){var b,c;var g=document.getElementsByTagName("FORM");if(null!=g){for(b=0;b<g.length;b++){var d=g[b].elements;var f="";var h=null;for(c=0;c<d.length;c++){var e=d[c];if(e.name&&"hidden"!=e.type){var k=e.name.indexOf("__");0>k||(k=e.name.substring(k+2,e.name.length),k!=h&&(null!=h&&(f+=";"),h=k),"checkbox"==e.type?f+=e.checked?"1":"0":"select-one"==e.type?f+=e.options[e.selectedIndex].value+":"+e.options[e.selectedIndex].text:"radio"==e.type?e.checked&&(f+=e.value):f+=e.value,
f+="\t")}}if("select-one"==a.type&&(d=document.getElementsByName(a.name))&&1<d.length)for(l=0;l<d.length;l++)d[l].length++,d[l].options[a.length-1].value=f,d[l].options[a.length-1].text="Ctrl-C",d[l].selectedIndex=a.length-1}isEndInitEvent()&&$("table#viewTable").resizeView()}return f}
function ctrlCV(a){var b=event.keyCode;var c=event.ctrlKey;keychar=String.fromCharCode(b).toUpperCase();if(c&&null!=a)if(event.preventDefault?(event.preventDefault(),event.stopPropagation()):(event.returnValue=!1,event.cancelBubble=!0),b=-1<navigator.userAgent.toLowerCase().indexOf("edge"),c=-1<navigator.userAgent.toLowerCase().indexOf("chrome"),b=b||c,"C"==keychar){var g=bulkPaste(a);g=null!=g?g:a.value;setClipboard(b,replaceAll(g,"\t","\r\n"))}else"B"==keychar?(g=bulkPasteBox(a),g=null!=g?g:a.value,
setClipboard(b,replaceAll(g,";","\r\n"))):"V"==keychar?getClipboard(b,function(d){g=replaceAll(d,"\r\n","\t");if("select-one"==a.type){if((d=document.getElementsByName(a.name))&&1<d.length){for(i=0;i<d.length;i++)d[i].length++,d[i].options[a.length-1].value=g,d[i].options[a.length-1].text="Ctrl-V",d[i].selectedIndex=a.length-1,d[i].value=g;isEndInitEvent()&&$("table#viewTable").resizeView()}}else a.value=g;bulkSet(a)}):"X"==keychar&&(a.value="",bulkSet(a))}
function setClipboard(a,b){a?navigator.clipboard?navigator.clipboard.writeText(b):(a=document.createElement("textarea"),a.setAttribute("id","target"),a.setAttribute("type","hidden"),a.value=b,document.body.appendChild(a),a.select(),document.execCommand("copy"),document.body.removeChild(a)):window.clipboardData.setData("text",b)}
function getClipboard(a,b){if(a)if(navigator.clipboard)navigator.clipboard.readText().then(function(g){b(g)});else{a=document.createElement("textarea");a.setAttribute("id","target");document.body.appendChild(a);a.focus();if(document.execCommand("paste")){var c=a.value;b(c)}else alert("\u30bb\u30ad\u30e5\u30ea\u30c6\u30a3\u306e\u95a2\u4fc2\u3067\u3001\u30da\u30fc\u30b9\u30c8\u3067\u304d\u307e\u305b\u3093\u3067\u3057\u305f\u3002");document.body.removeChild(a)}else c=window.clipboardData.getData("text"),
b(c)}function replaceAll(a,b,c){return a.split(b).join(c)}window.onbeforeprint=BeforPrint;window.onafterprint=AfterPrint;
function BeforPrint(){var a;var b=document.getElementsByName("divheader");var c=document.getElementsByName("layer");if(null!=b&&null!=c){for(a=0;a<b.length;a++)b[a].style.display="none";for(a=0;a<c.length;a++)c[a].oldScrollTop=c[a].scrollTop,c[a].scrollTop=0,c[a].oldWidth=c[a].style.width,c[a].style.width="",c[a].oldHeight=c[a].style.height,c[a].style.height="",c[a].oldOverflowX=c[a].style.overflowX,c[a].style.overflowX="visible",c[a].oldOverflowY=c[a].style.overflowY,c[a].style.overflowY="visible"}b=
document.getElementsByName("viewTable");if(null!=b)for(a=0;a<b.length;a++)b[a].oldFrame=b[a].frame,b[a].frame="box",b[a].oldBorderCollapse=b[a].style.borderCollapse,b[a].style.borderCollapse="collapse",b[a].oldCellspacing=b[a].cellspacing,b[a].cellspacing="0px"}
function AfterPrint(){var a;var b=document.getElementsByName("viewTable");if(null!=b)for(a=0;a<b.length;a++)b[a].style.borderCollapse=b[a].oldBorderCollapse,b[a].frame=b[a].oldFrame,b[a].cellspacing=b[a].oldCellspacing;b=document.getElementsByName("divheader");var c=document.getElementsByName("layer");if(null!=b&&null!=c){for(a=0;a<b.length;a++)b[a].style.display="block";for(a=0;a<c.length;a++)c[a].style.overflowX=c[a].oldOverflowX,c[a].style.overflowY=c[a].oldOverflowY,c[a].style.width=c[a].oldWidth,
c[a].style.height=c[a].oldHeight,c[a].scrollTop=c[a].oldScrollTop}}function setPageTiming(a){if((document.attachEvent?"complete"==document.readyState:1)&&parent.QUERY&&parent.QUERY.timecheck){a=document.getElementById("queryTime");var b=document.getElementById("viewTime");parent.QUERY.timecheck(a,b)}}
document.addEventListener?document.getBoxObjectFor?document.addEventListener("DOMContentLoaded",setPageTiming,null):window.addEventListener("load",setPageTiming,!1):document.attachEvent?document.attachEvent("onreadystatechange",setPageTiming):window.addEventListener("load",setPageTiming,!1);$(function(){$(".orgRowCntMsg").filter(":gt(0)").remove().end().filter(":first").replaceAll("#rowCountMessage")});
